@@ -29,17 +29,20 @@ class TestCycleService:
 
     @classmethod
     def get_run_env(cls):
-        env = os.getenv('ENV', '') or os.getenv('ENVIRONMENT', '') or os.getenv('CI_COMMIT_BRANCH', '')
+        env = os.getenv('ENV', '') or os.getenv('ENVIRONMENT', '') \
+              or os.getenv('CI_ENVIRONMENT', '') or os.getenv('CI_COMMIT_BRANCH', '')
         env = str(env).lower()
         if not env:
             env = 'local'
         if env == 'master':
-            env = 'production'
+            env = 'development'
+        if env.startswith('feature') or env.startswith('task'):
+            env = 'test1'
         if env not in ['local',
-                       'test1',
+                       'test1', 'test-1',
                        'develop', 'dev', 'development',
                        'test', 'testing',
                        'stage', 'staging', 'stg',
-                       'pro', 'production']:
+                       'pro', 'production', 'prod']:
             env = 'test1'
         return env
